==> aliyun-java-sdk-ecs-3.2.0-sources.jar: com/aliyuncs/ecs/transform/v20140526/EipFillParamsResponseUnmarshaller.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.aliyuncs.ecs.transform.v20140526;

import com.aliyuncs.ecs.model.v20140526.EipFillParamsResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class EipFillParamsResponseUnmarshaller {

	public static EipFillParamsResponse unmarshall(EipFillParamsResponse eipFillParamsResponse, UnmarshallerContext context) {
		
		eipFillParamsResponse.setrequestId(context.stringValue("EipFillParamsResponse.requestId"));
		eipFillParamsResponse.setdata(context.stringValue("EipFillParamsResponse.data"));
		eipFillParamsResponse.setcode(context.stringValue("EipFillParamsResponse.code"));
		eipFillParamsResponse.setsuccess(context.booleanValue("EipFillParamsResponse.success"));
		eipFillParamsResponse.setmessage(context.stringValue("EipFillParamsResponse.message"));
	 
	 	return eipFillParamsResponse;
	}
}

==> aliyun-java-sdk-ecs-4.1.0-sources.jar: com/aliyuncs/ecs/transform/v20140526/EipFillParamsResponseUnmarshaller.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.aliyuncs.ecs.transform.v20140526;

import com.aliyuncs.ecs.model.v20140526.EipFillParamsResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class EipFillParamsResponseUnmarshaller {

	public static EipFillParamsResponse unmarshall(EipFillParamsResponse eipFillParamsResponse, UnmarshallerContext context) {
		
		eipFillParamsResponse.setRequestId(context.stringValue("EipFillParamsResponse.requestId"));
		eipFillParamsResponse.setData(context.stringValue("EipFillParamsResponse.data"));
		eipFillParamsResponse.setCode(context.stringValue("EipFillParamsResponse.code"));
		eipFillParamsResponse.setSuccess(context.booleanValue("EipFillParamsResponse.success"));
		eipFillParamsResponse.setMessage(context.stringValue("EipFillParamsResponse.message"));
	 
	 	return eipFillParamsResponse;
	}
}
